Module zstd_common

Module zstd_common 

Functions

ZSTD_getErrorCode
Convert a result into an error code, which can be compared to the errors enum list
ZSTD_getErrorName
Provides a readable error string from a function result
ZSTD_getErrorString
Provides a readable error string from an error code
ZSTD_isDeterministicBuild
This is mainly used for Zstd’s determinism test suite, which is only run when this function returns 1.
ZSTD_isError
Most functions returning a size_t value can be tested for errors, using ZSTD_isError.
ZSTD_versionNumber
Get the zstd version number
ZSTD_versionString
Get a zstd version string