pub extern "C" fn ZSTD_getErrorCode(code: size_t) -> ZSTD_ErrorCodeExpand description
Convert a result into an error code, which can be compared to the errors enum list
pub extern "C" fn ZSTD_getErrorCode(code: size_t) -> ZSTD_ErrorCodeConvert a result into an error code, which can be compared to the errors enum list