ZSTD_getErrorString

Function ZSTD_getErrorString 

pub extern "C" fn ZSTD_getErrorString(
    code: ZSTD_ErrorCode,
) -> *const c_char
Provides a readable error string from an error code

Unlike ZSTD_getErrorName, this method should not be used on size_t function results