Module zstd

Module zstd 

Modules

experimental

Structs

ZSTD_ResetDirective
ZSTD_cParameter
ZSTD_compressionParameters
ZSTD_customMem
ZSTD_dParameter
The advanced API pushes parameters one by one into an existing ZSTD_DCtx decompression context. Parameters are sticky, and remain valid for all following frames using the same context.
ZSTD_dictAttachPref_e
Note: this enum and the behavior it controls are effectively internal implementation details of the compressor. They are expected to continue to evolve and should be considered only in the context of extremely advanced performance tuning.
ZSTD_format_e
ZSTD_frameParameters
ZSTD_frameProgression
ZSTD_inBuffer_s
ZSTD_outBuffer_s
ZSTD_parameters

Enums

BufferMode
Format
ZSTD_ParamSwitch_e
Note: this enum controls features which are conditionally beneficial.

Constants

ZSTD_BLOCKSIZELOG_MAX
ZSTD_BLOCKSIZE_MAX
ZSTD_BLOCKSIZE_MAX_MIN
The minimum valid max blocksize. Maximum blocksizes smaller than this make ZSTD_compressBound inaccurate.
ZSTD_CLEVEL_DEFAULT
ZSTD_CONTENTSIZE_ERROR
ZSTD_CONTENTSIZE_UNKNOWN
ZSTD_FRAMEHEADERSIZE_MAX
ZSTD_MAGICNUMBER
ZSTD_MAGIC_DICTIONARY
ZSTD_MAGIC_SKIPPABLE_MASK
ZSTD_MAGIC_SKIPPABLE_START
ZSTD_SKIPPABLEHEADERSIZE
ZSTD_VERSION_MAJOR
ZSTD_VERSION_MINOR
ZSTD_VERSION_NUMBER
ZSTD_VERSION_RELEASE
ZSTD_WINDOWLOG_ABSOLUTEMIN
ZSTD_WINDOWLOG_LIMIT_DEFAULT
By default, the streaming decoder will refuse any frame requiring larger than (1<<ZSTD_WINDOWLOG_LIMIT_DEFAULT) window size to preserve host’s memory from unreasonable requirements. This limit can be overridden using ZSTD_DCtx_setParameter.
ZSTD_WINDOWLOG_MAX
ZSTD_WINDOWLOG_MAX_32
ZSTD_WINDOWLOG_MAX_64
ZSTD_bm_buffered
ZSTD_bm_stable
ZSTD_btlazy2
ZSTD_btopt
ZSTD_btultra
ZSTD_btultra2
ZSTD_dct_auto
Dictionary is “full” when starting with ZSTD_MAGIC_DICTIONARY, otherwise it is “rawContent”
ZSTD_dct_fullDict
Refuses to load a dictionary if it does not respect Zstandard’s specification, starting with ZSTD_MAGIC_DICTIONARY
ZSTD_dct_rawContent
Ensures dictionary is always loaded as rawContent, even if it starts with ZSTD_MAGIC_DICTIONARY
ZSTD_dfast
ZSTD_dlm_byCopy
Copy dictionary content internally
ZSTD_dlm_byRef
Reference dictionary content – the dictionary buffer must outlive its users
ZSTD_error_GENERIC
ZSTD_error_cannotProduce_uncompressedBlock
ZSTD_error_checksum_wrong
ZSTD_error_corruption_detected
ZSTD_error_dictionaryCreation_failed
ZSTD_error_dictionary_corrupted
ZSTD_error_dictionary_wrong
ZSTD_error_dstBuffer_null
ZSTD_error_dstBuffer_wrong
ZSTD_error_dstSize_tooSmall
ZSTD_error_externalSequences_invalid
ZSTD_error_frameIndex_tooLarge
ZSTD_error_frameParameter_unsupported
ZSTD_error_frameParameter_windowTooLarge
ZSTD_error_init_missing
ZSTD_error_literals_headerWrong
ZSTD_error_maxCode
ZSTD_error_maxSymbolValue_tooLarge
ZSTD_error_maxSymbolValue_tooSmall
ZSTD_error_memory_allocation
ZSTD_error_noForwardProgress_destFull
ZSTD_error_noForwardProgress_inputEmpty
ZSTD_error_no_error
ZSTD_error_parameter_combination_unsupported
ZSTD_error_parameter_outOfBound
ZSTD_error_parameter_unsupported
ZSTD_error_prefix_unknown
ZSTD_error_seekableIO
ZSTD_error_sequenceProducer_failed
ZSTD_error_srcBuffer_wrong
ZSTD_error_srcSize_wrong
ZSTD_error_stabilityCondition_notRespected
ZSTD_error_stage_wrong
ZSTD_error_tableLog_tooLarge
ZSTD_error_version_unsupported
ZSTD_error_workSpace_tooSmall
ZSTD_fast
ZSTD_greedy
ZSTD_lazy
ZSTD_lazy2

Type Aliases

ZSTD_ErrorCode
ZSTD_allocFunction
ZSTD_bufferMode_e
ZSTD_dictContentType_e
This enum specifies the content type of a dictionary, either ZSTD_dct_auto, ZSTD_dct_rawContent, or ZSTD_dct_fullDict.
ZSTD_dictLoadMethod_e
This enum specifies the method used to load a dictionary, either ZSTD_dlm_byCopy or ZSTD_dlm_byRef.
ZSTD_freeFunction
ZSTD_inBuffer
ZSTD_outBuffer
ZSTD_strategy