pub enum ZSTD_ParamSwitch_e {
ZSTD_ps_auto = 0,
ZSTD_ps_enable = 1,
ZSTD_ps_disable = 2,
}Expand description
Note: this enum controls features which are conditionally beneficial.
Zstd can take a decision on whether or not to enable the feature (ZSTD_ps_auto),
or set the switch to ZSTD_ps_enable or ZSTD_ps_disable force enable/disable the feature.
Variants
ZSTD_ps_auto = 0
Let the library automatically determine whether the feature shall be enabled
ZSTD_ps_enable = 1
Force-enable the feature
ZSTD_ps_disable = 2
Force-disable the feature
Implementations