Functions
- ZSTD_
getError Code - Convert a result into an error code, which can be compared to the errors enum list
- ZSTD_
getError Name - Provides a readable error string from a function result
- ZSTD_
getError String - Provides a readable error string from an error code
- ZSTD_
isDeterministic Build - This is mainly used for Zstd’s determinism test suite, which is only run when this function returns 1.
- ZSTD_
isError - Most functions returning a
size_tvalue can be tested for errors, usingZSTD_isError. - ZSTD_
version Number - Get the zstd version number
- ZSTD_
version String - Get a zstd version string