pub extern "C" fn ZSTD_getErrorString(
code: ZSTD_ErrorCode,
) -> *const c_charExpand description
Provides a readable error string from an error code
Unlike ZSTD_getErrorName, this method should not be used on size_t function results
pub extern "C" fn ZSTD_getErrorString(
code: ZSTD_ErrorCode,
) -> *const c_charProvides a readable error string from an error code
Unlike ZSTD_getErrorName, this method should not be used on size_t function results